@@ -27,12 +27,10 @@ class NotificationStack(Stack):
     '''
     This Stack ...
     '''
-    def __init__(self, scope: Construct, construct_id: str, pinpoint_app_name: str, apns_bundle_id: str, apns_certificate: str, apns_private_key: str,  **kwargs) -> None:
+    def __init__(self, scope: Construct, construct_id: str, pinpoint_app_name: str, apns_bundle_id: str, apns_certificate_path: str, apns_private_key_path: str,  **kwargs) -> None:
         super().__init__(scope, construct_id, **kwargs)
 
-        pinpoint_app = pinpoint.CfnApp(self, pinpoint_app_name, name=pinpoint_app_name) 
-        print(apns_certificate)
-        print(apns_private_key) 
+        pinpoint_app = pinpoint.CfnApp(self, pinpoint_app_name, name=pinpoint_app_name)  
 
 
         # cfn_aPNSSandbox_channel = pinpoint.CfnAPNSSandboxChannel(self, "{}-apns-sandbox".format(pinpoint_app_name),
